import typer
import os
import json


def welcome():
    typer.secho(
        r"""
#################################################################################
			     _____  
			   .'     `.            WELCOME TO FIRST
			  /         \            TIME SETUP
			 |           | 
			 '.  +^^^+  .'
			   `. \./ .'
			     |_|_|  
			     (___)    
			     (___)
			     `---'
##################################################################################
    """,
        fg=typer.colors.BRIGHT_YELLOW,
    )


def setup(config_dir):
    os.system("cls" if os.name == "nt" else "clear")
    welcome()
    while True:
        typer.secho(
            "Enter the absolute path of your git repo with the README file to save your ideas\n> ",
            fg=typer.colors.BRIGHT_GREEN,
            nl=False,
        )
        choice = input()

        # Check if valid path
        if not os.path.isdir(choice):
            typer.secho("Enter valid absolute path\n", fg=typer.colors.BRIGHT_RED)
            continue

        if not os.path.isdir(os.path.join(choice, ".git")):
            typer.secho(
                "Directory not initialized with git\n", fg=typer.colors.BRIGHT_RED
            )
            continue

        if not os.path.isfile(os.path.join(choice, "README.md")):
            typer.secho("Add a README.md to the repo\n", fg=typer.colors.BRIGHT_RED)
            continue

        # create config files
        if not os.path.isdir(config_dir):
            os.makedirs(config_dir)

        with open(os.path.join(config_dir, "config.json"), "w") as f:
            data = {"path": choice}
            f.write(json.dumps(data))

        typer.secho(
            "\nSuccessfully saved the changes!!\nRun the program again to start writing your ideas",
            fg=typer.colors.GREEN,
        )
        break



import os
import subprocess
import platform
import typer
import sys
from chalkit.git_commit import git_commit


def editor(path, view_only):
    rpath = os.path.join(path, "README.md")
    gpath = os.path.join(path, ".git")

    if not os.path.isfile(rpath):
        typer.secho(f"Error:File not found at {rpath}", fg=typer.colors.BRIGHT_RED)
        sys.exit()

    if not os.path.isdir(gpath):
        typer.secho(f"Error:Git not found at {gpath}", fg=typer.colors.BRIGHT_RED)
        sys.exit()

    if not view_only:
        typer.secho(
            "Enter the commit message\n> ", fg=typer.colors.BRIGHT_GREEN, nl=False
        )
        commit_message = input()
        if platform.system() == "Windows":
            nano_path = r"C:\Program Files\Git\usr\bin\nano.exe"
            if not os.path.isfile(nano_path):
                typer.secho(
                    f"Make sure nano is installed on correct path:{nano_path}",
                    fg=typer.colors.BRIGHT_RED,
                )
                sys.exit()
            subprocess.call((nano_path, rpath))
        else:
            subprocess.call(("nano", rpath))

        result = git_commit(commit_message, path)
        if result:
            typer.secho(f"Error: {result}", fg=typer.colors.BRIGHT_RED)

    else:
        if platform.system() == "Windows":
            nano_path = r"C:\Program Files\Git\usr\bin\nano.exe"
            if not os.path.isfile(nano_path):
                typer.secho(
                    f"Make sure nano is installed on correct path:{nano_path}",
                    fg=typer.colors.BRIGHT_RED,
                )
                sys.exit()
            subprocess.call((nano_path, "-v", rpath))
        else:
            subprocess.call(("nano", "-v", rpath))



import subprocess


def git_commit(commit_message, path):
    try:
        subprocess.Popen(
            f'git add -A && git commit -m "{commit_message}"', shell=True, cwd=path
        )
    except Exception as e:
        return e



import shutil
import typer


def rreset(path):
    typer.secho("Are you sure you want to reset? (y/n)")
    choice = input()
    if choice == "y":
        try:
            shutil.rmtree(path)
            typer.secho("Reset success!!", fg=typer.colors.BRIGHT_GREEN)
        except:
            typer.secho("Error: No configurations found", fg=typer.colors.BRIGHT_RED)
    else:
        typer.secho("Aborting!!!", fg=typer.colors.BRIGHT_GREEN)



import os
import json
import typer
from appdirs import user_config_dir
from chalkit.setup import setup
from chalkit.editor import editor
from chalkit.rreset import rreset

app = typer.Typer()
config_dir = user_config_dir("chalkit")


@app.command()
def chalkit(reset: bool = False, view: bool = False):
    if reset:
        rreset(config_dir)
    else:
        try:
            f = open(os.path.join(config_dir, "config.json"))
            data = json.load(f)
            path = data["path"]
            f.close()
            if view:
                editor(path, view_only=True)
            else:
                editor(path, view_only=False)
        except (FileNotFoundError, AttributeError, json.decoder.JSONDecodeError):
            setup(config_dir)
        except Exception as e:
            typer.secho(f"Error:{e}", fg=typer.colors.BRIGHT_RED)


app()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['chalkit']

package_data = \
{'': ['*']}

install_requires = \
['appdirs>=1.4.4,<2.0.0', 'typer[all]>=0.4.1,<0.5.0']

entry_points = \
{'console_scripts': ['chalkit = chalkit.main:app']}

setup_kwargs = {
    'name': 'chalkit',
    'version': '1.1.0',
    'description': 'CLI tool to write and save new ideas by just opening your terminal!',
    'long_description': '# chalkit\nChalkit is a CLI tool to save ideas/todos by just opening your terminal.\nThe git repository is automatically committed and pushed.\n\nLets you quickly type your ideas/todos using the terminal and continue on with your work.\n\n![Demo](https://github.com/Anurag-gg/chalkit/blob/main/assets/demo.gif)\n\n# Initital setup\nRequires a directory containing git repository with a README.md file in it.\nWhen you run chalkit for the first time, it asks for the absolute path for this directory.\n\nThe configuration files are stored as determined by user_config_dir mentioned by [appdirs](https://pypi.org/project/appdirs/)\n\n# How to install\n``` \n$ pip install chalkit\n```\n\n# Commands\n```\n $ eureka    First time setup, edit ur ideas\n```\n\n## Flags\n```\n$ --view      View your ideas in read-only mode\n$ --reset     Reset your configurations\n```\n# Improvements\nFeel free to raise issues, ask for features. Leave a star if helpful.',
    'author': 'Anurag-gg',
    'author_email': 'dsanurag520@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
